@@ -23,7 +23,9 @@ class VersionedResources(Resources):
     def publishTraverse(self, request, name):
         try:
             resource = super(VersionedResources, self).publishTraverse(request, name)
-        except NotFound:            
+            tStak = request.getTraversalStack()
+            request.setTraversalStack([_name_map.get(name,name) for name in tStak])             
+        except NotFound:                       
             orig_name = _name_map.get(name)
             
             if orig_name is None:
